pygeodesy.ltpTuples._AbcBase

Package pygeodesy :: Module ltpTuples :: Class _AbcBase |
[frames] | no frames]

# Class _AbcBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
                      _AbcBase

Known Subclasses:
  - Aer
  - , Ned

(INTERNAL) Base class for classes `Aer` and `Ned`.

Instance Methods
toAer(self, Aer=None, **name_Aer_kwds) Get the local Azimuth, Elevation, slant Range (AER) components. |
toEnu(self, Enu=None, **name_Enu_kwds) Get the local East, North, Up (ENU) components. |
toNed(self, Ned=None, **name_Ned_kwds) Get the local North, East, Down (NED) components. |
toXyz(self, Xyz=None, **name_Xyz_kwds) Get the local X, Y, Z (XYZ) components. |
Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr`, `toStr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| ltp Get the local tangent plane (Ltp).
| xyz Get the local `(X, Y, Z)` coordinates (Vector3Tuple`(x, y, z)`).
| xyz3 Get the local `(X, Y, Z)` coordinates as `3-tuple`.
| xyz4 Must be overloaded.
| xyzLocal Get this AER or NED as an XyzLocal.
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toAer (self, Aer=None, **name_Aer_kwds) |
Get the local Azimuth, Elevation, slant Range (AER) components. Arguments: `Aer` - Class to return AER (Aer) or `None`. `name_Aer_kwds` - Optional `name=NN` (`str`) and optionally, additional Aer keyword arguments, ignored if `Aer is None`. Returns: An `Aer` instance or an Aer4Tuple`(azimuth, elevation, slantrange, ltp)` if `Aer is None`. Raises: `TypeError` - Invalid `Aer` or `name_Aer_kwds`.

### toEnu (self, Enu=None, **name_Enu_kwds) |
Get the local East, North, Up (ENU) components. Arguments: `Enu` - Class to return ENU (Enu) or `None`. `name_Enu_kwds` - Optional `name=NN` (`str`) and optionally, additional Enu keyword arguments, ignored if `Enu is None`. Returns: An `Enu` instance or an Enu4Tuple`(east, north, up, ltp)` if `Enu is None`. Raises: `TypeError` - Invalid `Enu` or `name_Enu_kwds`.

### toNed (self, Ned=None, **name_Ned_kwds) |
Get the local North, East, Down (NED) components. Arguments: `Ned` - Class to return NED (Ned) or `None`. `name_Ned_kwds` - Optional `name=NN` (`str`) and optionally, additional Ned keyword arguments, ignored if `Ned is None`. Returns: An `Ned` instance or an Ned4Tuple`(north, east, down, ltp)` if `Ned is None`. Raises: `TypeError` - Invalid `Ned` or `name_Ned_kwds`.

### toXyz (self, Xyz=None, **name_Xyz_kwds) |
Get the local X, Y, Z (XYZ) components. Arguments: `Xyz` - Class to return XYZ (XyzLocal, Enu, Ned, Aer) or `None`. `name_Xyz_kwds` - Optional `name=NN` (`str`) and optionally, additional `Xyz` keyword arguments, ignored if `Xyz is None`. Returns: An `Xyz` instance or an Xyz4Tuple`(x, y, z, ltp)` if `Xyz is None`. Raises: `TypeError` - Invalid `Xyz` or `name_Xyz_kwds`.

Property Details

### ltp Get the local tangent plane (Ltp). Get method: ltp(self) - Get the local tangent plane (Ltp). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### xyz Get the local `(X, Y, Z)` coordinates (Vector3Tuple`(x, y, z)`). Get method: xyz(self) - Get the local `(X, Y, Z)` coordinates (Vector3Tuple`(x, y, z)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### xyz3 Get the local `(X, Y, Z)` coordinates as `3-tuple`. Get method: xyz3(self) - Get the local `(X, Y, Z)` coordinates as `3-tuple`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### xyz4 Must be overloaded. Get method: xyz4(self) - Must be overloaded. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### xyzLocal Get this AER or NED as an XyzLocal. Get method: xyzLocal(self) - Get this AER or NED as an XyzLocal. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.